@@ -1,15 +1,14 @@
 """
 Model fields for working with trees.
 """
-from __future__ import unicode_literals
-
-__all__ = ('TreeForeignKey', 'TreeOneToOneField', 'TreeManyToManyField')
-
 from django.db import models
 from django.conf import settings
 from mptt.forms import TreeNodeChoiceField, TreeNodeMultipleChoiceField
 
 
+__all__ = ('TreeForeignKey', 'TreeOneToOneField', 'TreeManyToManyField')
+
+
 class TreeForeignKey(models.ForeignKey):
     """
     Extends the foreign key, but uses mptt's ``TreeNodeChoiceField`` as
@@ -37,10 +36,3 @@ class TreeManyToManyField(models.ManyToManyField):
     def formfield(self, **kwargs):
         kwargs.setdefault('form_class', TreeNodeMultipleChoiceField)
         return super(TreeManyToManyField, self).formfield(**kwargs)
-
-# South integration
-if 'south' in settings.INSTALLED_APPS:  # pragma: no cover
-    from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], ["^mptt\.fields\.TreeForeignKey"])
-    add_introspection_rules([], ["^mptt\.fields\.TreeOneToOneField"])
-    add_introspection_rules([], ["^mptt\.fields\.TreeManyToManyField"])
