@@ -7,7 +7,7 @@ from django.db.models.base import ModelBase
 from django.db.models.query import Q
 from django.db.models.query_utils import DeferredAttribute
 
-from django.utils.translation import ugettext as _
+from django.utils.translation import gettext as _
 
 from mptt.compat import cached_field_value
 from mptt.fields import TreeForeignKey, TreeOneToOneField, TreeManyToManyField
@@ -800,7 +800,7 @@ class MPTTModel(models.Model, metaclass=MPTTModelBase):
         self._tree_manager.move_node(self, target, position)
 
     def _is_saved(self, using=None):
-        if not self.pk or self._mpttfield('tree_id') is None:
+        if self.pk is None or self._mpttfield('tree_id') is None:
             return False
         opts = self._meta
         if opts.pk.remote_field is None:
@@ -910,15 +910,14 @@ class MPTTModel(models.Model, metaclass=MPTTModelBase):
                 same_order = True
 
             if not same_order:
+                parent = getattr(self, opts.parent_attr)
                 opts.set_raw_field_value(self, opts.parent_attr, old_parent_id)
                 try:
                     right_sibling = None
                     if opts.order_insertion_by:
-                        right_sibling = opts.get_ordered_insertion_target(
-                            self, getattr(self, opts.parent_attr))
+                        right_sibling = opts.get_ordered_insertion_target(self, parent)
 
                     if parent_id is not None:
-                        parent = getattr(self, opts.parent_attr)
                         # If we aren't already a descendant of the new parent,
                         # we need to update the parent.rght so things like
                         # get_children and get_descendant_count work correctly.
