@@ -1518,8 +1518,10 @@ class DrilldownTreeTestCase(TreeTestCase):
         {% endfor %}
         ''')
 
-    def render_for_node(self, pk, cumulative=False, m2m=False):
+    def render_for_node(self, pk, cumulative=False, m2m=False, all_descendants=False):
         template = self.template
+        if all_descendants:
+            template = template.replace(' count myapp.Game.genre in game_count ', ' all_descendants ')
         if cumulative:
             template = template.replace(' count ', ' cumulative count ')
         if m2m:
@@ -1563,6 +1565,13 @@ class DrilldownTreeTestCase(TreeTestCase):
             self.render_for_node(2, cumulative=True, m2m=True),
             '1:,[2:],3:2,4:3,5:4')
 
+        self.assertEqual(
+            self.render_for_node(1, all_descendants=True),
+            '[1:],2:,3:,4:,5:,6:,7:,8:')
+        self.assertEqual(
+            self.render_for_node(2, all_descendants=True),
+            '1:,[2:],3:,4:,5:')
+
 
 class TestAutoNowDateFieldModel(TreeTestCase):
     # https://github.com/django-mptt/django-mptt/issues/175
@@ -1643,7 +1652,7 @@ class AdminBatch(TreeTestCase):
             '_selected_action': ['5', '8', '9'],
         }
         response = self.client.post('/admin/myapp/category/', data)
-        self.assertContains(response, 'value="Yes, I\'m sure"', 1)
+        self.assertRegex(response.rendered_content, r'value="Yes, I(\'|’)m sure"')
 
         data['post'] = 'yes'
         response = self.client.post('/admin/myapp/category/', data)
