@@ -1,6 +1,7 @@
-from __future__ import unicode_literals
 import os
 
+import django
+
 DIRNAME = os.path.dirname(__file__)
 
 DEBUG = True
@@ -17,20 +18,20 @@ INSTALLED_APPS = (
     'django.contrib.contenttypes',
     'django.contrib.messages',
     'django.contrib.sessions',
+    'django.contrib.staticfiles',
     'mptt',
     'myapp',
 )
 
 STATIC_URL = '/static/'
 SECRET_KEY = 'abc123'
-MIDDLEWARE_CLASSES = (
+MIDDLEWARE = [
     'django.middleware.common.CommonMiddleware',
     'django.contrib.sessions.middleware.SessionMiddleware',
     'django.middleware.csrf.CsrfViewMiddleware',
     'django.contrib.auth.middleware.AuthenticationMiddleware',
     'django.contrib.messages.middleware.MessageMiddleware',
-    'django.contrib.auth.middleware.SessionAuthenticationMiddleware',
-)
+]
 
 TEMPLATES = [
     {
